Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7511)

Unified Diff: chrome/browser/shell_integration.h

Issue 1586143002: Cleanup dual_mode handling in ShellIntegrationWin after Metro removal. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@a1_cleanup_scottmg
Patch Set: nits Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/shell_integration_win.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/shell_integration.h
diff --git a/chrome/browser/shell_integration.h b/chrome/browser/shell_integration.h
index b9a5bb39b40634d05350a3fad4129f1fb4f3d1bd..7073b88f8097b49e3022bcc0c0f78e2f0fe7f990 100644
--- a/chrome/browser/shell_integration.h
+++ b/chrome/browser/shell_integration.h
@@ -160,16 +160,15 @@ class ShellIntegration {
static void MigrateChromiumShortcuts();
// Migrates all shortcuts in |path| which point to |chrome_exe| such that they
// have the appropriate AppUserModelId. Also makes sure those shortcuts have
// the dual_mode (ref. shell_util.h) property set if such is requested by
// |check_dual_mode|.
// Returns the number of shortcuts migrated.
// This method should not be called prior to Windows 7.
// This method is only public for the sake of tests and shouldn't be called
// externally otherwise.
static int MigrateShortcutsInPathInternal(const base::FilePath& chrome_exe,
const base::FilePath& path,
- bool check_dual_mode);
+ bool clear_dual_mode);
// Returns the path to the Start Menu shortcut for the given Chrome.
static base::FilePath GetStartMenuShortcut(const base::FilePath& chrome_exe);
« no previous file with comments | « no previous file | chrome/browser/shell_integration_win.cc » ('j') | no next file with comments »
@@ -160,16 +160,15 @@ class ShellIntegration {
static void MigrateChromiumShortcuts();
// Migrates all shortcuts in |path| which point to |chrome_exe| such that they
- // have the appropriate AppUserModelId. Also makes sure those shortcuts have
- // the dual_mode (ref. shell_util.h) property set if such is requested by
- // |check_dual_mode|.
+ // have the appropriate AppUserModelId. Also clears the dual_mode property
+ // from shortcuts that previously had it if requested by |clear_dual_mode|.
// Returns the number of shortcuts migrated.
// This method should not be called prior to Windows 7.

Powered by Google App Engine
This is Rietveld 408576698